@@ -1,10 +1,13 @@
+from __future__ import annotations
+
 import re
 from distutils.spawn import find_executable
+from itertools import chain
 from subprocess import CalledProcessError, check_call, check_output
 
 
 class ElfPatcher:
-    def replace_needed(self, file_name: str, so_name: str, new_so_name: str) -> None:
+    def replace_needed(self, file_name: str, *old_new_pairs: tuple[str, str]) -> None:
         raise NotImplementedError
 
     def set_soname(self, file_name: str, new_so_name: str) -> None:
@@ -30,10 +33,10 @@ def _verify_patchelf() -> None:
         raise ValueError("Could not call `patchelf` binary")
 
     m = re.match(r"patchelf\s+(\d+(.\d+)?)", version)
-    if m and tuple(int(x) for x in m.group(1).split(".")) >= (0, 9):
+    if m and tuple(int(x) for x in m.group(1).split(".")) >= (0, 14):
         return
     raise ValueError(
-        ("patchelf %s found. auditwheel repair requires " "patchelf >= 0.9.") % version
+        f"patchelf {version} found. auditwheel repair requires " "patchelf >= 0.14."
     )
 
 
@@ -41,19 +44,25 @@ class Patchelf(ElfPatcher):
     def __init__(self) -> None:
         _verify_patchelf()
 
-    def replace_needed(self, file_name: str, so_name: str, new_so_name: str) -> None:
-        check_call(["patchelf", "--replace-needed", so_name, new_so_name, file_name])
+    def replace_needed(self, file_name: str, *old_new_pairs: tuple[str, str]) -> None:
+        check_call(
+            [
+                "patchelf",
+                *chain.from_iterable(
+                    ("--replace-needed", *pair) for pair in old_new_pairs
+                ),
+                file_name,
+            ]
+        )
 
     def set_soname(self, file_name: str, new_so_name: str) -> None:
         check_call(["patchelf", "--set-soname", new_so_name, file_name])
 
     def set_rpath(self, file_name: str, rpath: str) -> None:
-
         check_call(["patchelf", "--remove-rpath", file_name])
         check_call(["patchelf", "--force-rpath", "--set-rpath", rpath, file_name])
 
     def get_rpath(self, file_name: str) -> str:
-
         return (
             check_output(["patchelf", "--print-rpath", file_name])
             .decode("utf-8")
