@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import itertools
 import logging
 import os
@@ -9,7 +11,7 @@ from collections import OrderedDict
 from os.path import abspath, basename, dirname, exists, isabs
 from os.path import join as pjoin
 from subprocess import check_call
-from typing import Dict, Iterable, List, Optional, Tuple
+from typing import Iterable
 
 from auditwheel.patcher import ElfPatcher
 
@@ -32,21 +34,21 @@ WHEEL_INFO_RE = re.compile(
 
 def repair_wheel(
     wheel_path: str,
-    abis: List[str],
+    abis: list[str],
     lib_sdir: str,
     out_dir: str,
     update_tags: bool,
     patcher: ElfPatcher,
+    exclude: list[str],
     strip: bool = False,
-) -> Optional[str]:
-
+) -> str | None:
     external_refs_by_fn = get_wheel_elfdata(wheel_path)[1]
 
     # Do not repair a pure wheel, i.e. has no external refs
     if not external_refs_by_fn:
         return None
 
-    soname_map = {}  # type: Dict[str, Tuple[str, str]]
+    soname_map: dict[str, tuple[str, str]] = {}
     if not isabs(out_dir):
         out_dir = abspath(out_dir)
 
@@ -67,9 +69,13 @@ def repair_wheel(
         # here, fn is a path to a python extension library in
         # the wheel, and v['libs'] contains its required libs
         for fn, v in external_refs_by_fn.items():
-
-            ext_libs = v[abis[0]]["libs"]  # type: Dict[str, str]
+            ext_libs: dict[str, str] = v[abis[0]]["libs"]
+            replacements: list[tuple[str, str]] = []
             for soname, src_path in ext_libs.items():
+                if soname in exclude:
+                    logger.info(f"Excluding {soname}")
+                    continue
+
                 if src_path is None:
                     raise ValueError(
                         (
@@ -81,7 +87,9 @@ def repair_wheel(
 
                 new_soname, new_path = copylib(src_path, dest_dir, patcher)
                 soname_map[soname] = (new_soname, new_path)
-                patcher.replace_needed(fn, soname, new_soname)
+                replacements.append((soname, new_soname))
+            if replacements:
+                patcher.replace_needed(fn, *replacements)
 
             if len(ext_libs) > 0:
                 new_rpath = os.path.relpath(dest_dir, os.path.dirname(fn))
@@ -94,9 +102,12 @@ def repair_wheel(
         # name of the other.
         for old_soname, (new_soname, path) in soname_map.items():
             needed = elf_read_dt_needed(path)
+            replacements = []
             for n in needed:
                 if n in soname_map:
-                    patcher.replace_needed(path, n, soname_map[n][0])
+                    replacements.append((n, soname_map[n][0]))
+            if replacements:
+                patcher.replace_needed(path, *replacements)
 
         if update_tags:
             ctx.out_wheel = add_platforms(ctx, abis, get_replace_platforms(abis[0]))
@@ -115,7 +126,7 @@ def strip_symbols(libraries: Iterable[str]) -> None:
         check_call(["strip", "-s", lib])
 
 
-def copylib(src_path: str, dest_dir: str, patcher: ElfPatcher) -> Tuple[str, str]:
+def copylib(src_path: str, dest_dir: str, patcher: ElfPatcher) -> tuple[str, str]:
     """Graft a shared library from the system into the wheel and update the
     relevant links.
 
