@@ -1,11 +1,14 @@
-''' Contexts for *with* statement providing temporary directories
-'''
+""" Contexts for *with* statement providing temporary directories
+"""
+from __future__ import annotations
+
 import os
 from tempfile import TemporaryDirectory
+from types import TracebackType
 
 
 class InTemporaryDirectory:
-    ''' Create, return, and change directory to a temporary directory
+    """Create, return, and change directory to a temporary directory
 
     Examples
     --------
@@ -19,27 +22,32 @@ class InTemporaryDirectory:
     False
     >>> os.getcwd() == my_cwd
     True
-    '''
+    """
 
-    def __init__(self):
+    def __init__(self) -> None:
         self._tmpdir = TemporaryDirectory()
 
     @property
-    def name(self):
+    def name(self) -> str:
         return self._tmpdir.name
 
-    def __enter__(self):
+    def __enter__(self) -> str:
         self._pwd = os.getcwd()
         os.chdir(self._tmpdir.name)
         return self._tmpdir.__enter__()
 
-    def __exit__(self, exc, value, tb):
+    def __exit__(
+        self,
+        exc: type[BaseException] | None,
+        value: BaseException | None,
+        tb: TracebackType | None,
+    ) -> None:
         os.chdir(self._pwd)
         return self._tmpdir.__exit__(exc, value, tb)
 
 
 class InGivenDirectory:
-    """ Change directory to given directory for duration of ``with`` block
+    """Change directory to given directory for duration of ``with`` block
 
     Useful when you want to use `InTemporaryDirectory` for the final test, but
     you are still debugging.  For example, you may want to do this in the end:
@@ -62,8 +70,8 @@ class InGivenDirectory:
     again.
     """
 
-    def __init__(self, path=None):
-        """ Initialize directory context manager
+    def __init__(self, path: str | None = None) -> None:
+        """Initialize directory context manager
 
         Parameters
         ----------
@@ -75,12 +83,17 @@ class InGivenDirectory:
             path = os.getcwd()
         self.name = os.path.abspath(path)
 
-    def __enter__(self):
+    def __enter__(self) -> str:
         self._pwd = os.path.abspath(os.getcwd())
         if not os.path.isdir(self.name):
             os.mkdir(self.name)
         os.chdir(self.name)
         return self.name
 
-    def __exit__(self, exc, value, tb):
+    def __exit__(
+        self,
+        exc: type[BaseException] | None,
+        value: BaseException | None,
+        tb: TracebackType | None,
+    ) -> None:
         os.chdir(self._pwd)
